#
# spec file for package xfstests
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# We only want DMAPI for SLE11/12
%if 0%{?sle_version} >= 120000 && 0%{?sle_version} < 150000
%define need_dmapi 1
%endif

%if 0%{?sles_version} == 11
%define need_dmapi 1
%endif

%define version_unconverted 1.1.1+git.20180506
Name:           xfstests
Version:        1.1.1+git.20180506
Release:        1.2
Summary:        Filesystem regression test suite
License:        GPL-2.0-or-later
Group:          System/Filesystems
Url:            http://oss.sgi.com/projects/xfs/
Source:         xfstests-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
%if 0%{?need_dmapi}
BuildRequires:  dmapi-devel
%endif
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  gdbm-devel
BuildRequires:  libacl-devel
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libbtrfs-devel
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  make
BuildRequires:  openssl-devel
BuildRequires:  xfsprogs-devel
BuildRequires:  xz
Requires:       acl
Requires:       attr
Requires:       bash
Requires:       bc
Requires:       bind-utils
Requires:       btrfsprogs
Requires:       e2fsprogs
Requires:       perl
Requires:       quota
Requires:       xfsdump
Requires:       xfsprogs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The filesystem regression test suite.  Also includes some support for acl,
attr, dmapi, udf, reiserfs, nfs, btrfs testing.  Contains around 400+ specific
tests for userspace & kernelspace.

%prep
%setup -q

%build
export OPTIMIZER="-fPIC"
export CFLAGS="%{optflags} -Iinclude"
INSTALL_USER=`id -un`
INSTALL_GROUP=`id -gn`
export INSTALL_USER INSTALL_GROUP
autoreconf -fiv --include=m4
libtoolize -i
%configure		\
  --disable-static	\
  --exec_prefix=/var/lib
make %{?_smp_mflags} V=1

%install
DIST_ROOT=%{buildroot}
DIST_INSTALL=`pwd`/install.manifest
export DIST_ROOT DIST_INSTALL
make %{?_smp_mflags} DESTDIR=%{buildroot} install DIST_ROOT=%{buildroot} DIST_MANIFEST="$DIST_INSTALL"
make -C build/rpm rpmfiles DESTDIR=%{buildroot} DIST_MANIFEST="$DIST_INSTALL"
%fdupes %{buildroot}/%{_prefix}

%files
%defattr(-,root,root)
/var/lib/xfstests

%changelog
* Tue May  8 2018 dsterba@suse.cz
- Update to version 1.1.1+git.20180506
* Wed Mar 14 2018 jeffm@suse.com
- Only require dmapi-devel for SLE11/12.
* Wed Mar 14 2018 opensuse-packaging@opensuse.org
- Update to version 1.1.1+git.20180308:
  * btrfs/146: make sure hit all stripes in the case of compression
  * btrfs/004: increase the buffer size of logical-resolve to the maximum value 64K
  * generic: test fsync new file after removing hard link
  * generic: add test for fsync after renaming and linking special file
  * overlay: correct scratch dirs check
  * overlay: skip check for tests finished with corrupt filesystem
  * overlay/003: fix fs check failure
  * overlay: hook filesystem check helper
  * common/rc: improve dev mounted check helper
* Tue Feb 27 2018 opensuse-packaging@opensuse.org
- Update to version 1.1.1+git.20180224:
  * fsstress: avoid infinite loops in clonerange_f
  * generic/47[23]: remove from auto/quick groups
  * common/xfs: Initialise OPTIND for getopts calls
  * common/rc: Fix fcollapse require code to work with 64k block size
  * fsx: Fix -P errors
  * fstests: _fail test by default when _scratch_mount fails
  * generic/25[02]: increase filesystem size
  * btrfs/150: add _scratch_dev_pool_get/put to run the test as expected
  * xfs/015: enlarge the initial fs size
  * generic: add OFD lock tests
  * xfs: rmapbt swapext block reservation overrun test
  * xfs: regression tests for reflink quota bugs
  * xfs/348: dir->symlink corruption must not be allowed
  * xfs_scrub: remove -y parameter
  * overlay: renumber tests after merge
  * overlay: add fsck.overlay impure xattr test
  * overlay: add fsck.overlay redirect directory test
  * overlay: add fsck.overlay whiteout test
  * overlay: define common overlay xattr keys
  * overlay: add filesystem check helper
  * generic/270: Check for scratch mount success
  * check: Fix exit status
  * overlay: test overlay file handle of dir with ancestor under lower redirect
  * overlay: test overlay file handles of lower dir with non-indexed ancestor
  * generic/{274,315}: Require falloc -k support
  * generic/307: Require ACL support
  * overlay: test encode/decode of non-samefs overlay file handles with renames
  * overlay: test encode/decode overlay file handles with renames
  * overlay: test encode/decode of non-samefs overlay file handles
  * overlay: test encode/decode overlay file handles
  * fstests: implement require of multiple overlayfs features
  * overlay: add a test for multiple redirects to the same lower dir
  * overlay/017: require and enable redirect_dir
  * overlay: consider index dir with whiteouts clean
  * overlay/036: fix upper/lower dir mismatch
  * ovelray: drop explicit use of OVERLAY_MOUNT_OPTIONS
  * src/metaperf: Include linux/param.h explicitly for HZ macro
  * src/dmiperf: Include sys/types.h for u_int32_t
  * xfs/24[356]: checking cow fork bmap requires CONFIG_XFS_DEBUG=y
  * generic/403: don't spew '$GETFATTR_PROG: Killed' messages
  * xfs/122: fix xfs header ordering problems
  * common/rc: report kmemleak errors
  * ext4: Ext4 online resize with bigalloc tests.
  * generic: test decoding file handles after cycle mount
  * generic/exportfs: golden output is not silent
  * src/open_by_handle: verify dir content only with -r flag
  * src/pwrite_mmap_blocked: Include signal.h instead of sys/signal.h
  * src/t_mtab: Replace sys_siglist[] with strsignal()
  * src/fssum: Use htobe64() instead of a custom macro
  * doio, growfiles: Use standard signal name SIGCHLD instead of SIGCLD
  * fstests: Replace all __[u]intNN_t types with standard [u]intNN_t
  * fsstress: Include stddef.h for ptrdiff_t
  * check: expunge tests when doing a dry run
  * check: move expunge test into a helper
  * xfs: Regression test for invalid sb_logsunit
  * common: Add _require_no_xfs_bug_on_assert and factor out filter_xfs_dmesg
  * xfs/realtime: Fix direct invocations of xfs_repair
  * xfs/realtime: add _require_no_rtinherit function
  * xfs/realtime: Add require_no_realtime function
  * common/dmthin: dm-thin lacks DAX support
  * common/xfs: Check if write supports [-c|-d] option in xfs_db
  * shared/272: don't use data journaling with DAX
  * btrfs/027: unmount scratch device if test fails
  * btrfs/011: umount device in _cleanup
  * fstests: Add 9p network filesystem support
  * generic/015: Change the test filesystem size to 101mb
  * filter: Introduce filter to filter out offset for xfs_io
  * xfs: test for umount hang caused by the pending dquota log item in AIL
  * common/rc: factor out _scratch_xfs_[get|set]_sb_field
  * dmflakey: support error_writes feature for dm-flakey
  * dmflakey: support multiple dm targets for a dm-flakey device
  * common/rc: ext4 doesn't support O_DIRECT with data journaling
  * common/rc: perform _require_metadata_journaling check on overlay base fs
  * xfs: find libxfs api violations
  * ext4: test for inline data + DAX corruption
  * ext4: test for DAX + journaling corruption
  * xfs/068: fix clonerange problems in file/dir count output
  * btrfs: make sure scrub fixes raid6 corruption
  * generic: run a long-soak write-only fsstress test
  * generic/050: fix _require_local_device $SCRATCH_DEV check order
  * fsstress: implement the clonerange/deduperange ioctls
  * generic: test error shutdown while stressing filesystem
  * ext4: use a slightly bigger file system in ext4/021
  * common/encrypt: Create an encrypted equivalent of _scratch_mkfs_sized
  * btrfs: Add new 'limit' test group for btrfs
  * xfs/040: document purpose
  * generic: add syncfs test
  * common/rc: check syncfs support
  * common/rc: add scratch shutdown support for overlayfs
  * fsstress: getcwd() return value fixes
  * fsstress: Eliminate valgrind noise
  * README: document group fsgqa is required
  * xfs: fix tests to handle removal of no-alloc create nonfeature
  * generic/45[34]: test line draw characters in file/attr names
  * common/xfs: fix scrub support probing again
  * build: update AC_PACKAGE_WANT_GDBM() and src/dbtest.c to build
  * generic/group: add 304 to dedupe group
  * generic: initial fiemap range query test
  * generic: Partial direct write test
  * generic: Test RWF_NOWAIT
  * common/rc: Check pwrite parameters in _require_xfs_io_command
  * common/populate: fix S_IFDIR.FMT_BLOCK and ATTR.FMT_LOCAL for ext4 encryption
  * common: rework _require_ext4_mkfs_feature
* Tue Dec 12 2017 dsterba@suse.cz
- Update to git version 20171210
- spec: fix build problems since the last upstream update
- Removed patches: no-ltinstall.diff, not needed anymore
* Sun Jan 29 2017 mpluskal@suse.com
- Update to version 1.1.1+git.20170127:
  * populate: discover XFS structure fields and fuzz verbs, and use them to fuzz fields
  * common/populate: create attrs in different namespaces
  * xfs: fuzz every field of every structure
  * fstests: fix wrong seq number in test
  * mvtest: change "FSQA Test No." when we renumber tests
  * xfs: test xfs_db source command
  * tools/nextid: pad 0 in next test id seq number
  * xfs/122: reduce xfs_dsb_t size
  * btrfs: setxattr on subvolume directory
  * generic: splitted large dio write could trigger assertion on btrfs
* Fri Nov 25 2016 dsterba@suse.cz
- Update to version 1.1.1+git.20161118:
  * xfs/021: filter out detailed array element info from xfs_db
  * xfs: testcase for kernelspace xfs_fsr extent handling flaw
  * fstests: fix fsx fallocate error messages
  * generic/37[3-4]: use bind mount instead of 2nd _scratch_mount
  * generic/38[3-6]: require project quota to be enabled on SCRATCH_DEV
  * generic: fix $tmp path in tests
  * xfs/298: cd to / instead of ~
  * generic/098: update test for truncating a file into the middle of a hole
  * generic: concurrent non-overlapping direct I/O on the same extents
  * fstests: Introduce check for explicit SHARED extent flag reporting
* Tue Oct  4 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160924:
  * xfs: various operations on mounted fs
  * common/rc: fix fsmap check
  * fstests: require scratch dev in tests using dm targets
  * xfs/260: fix output to match actions
  * xfs: modify quota tests to work on generic filesystems
  * fstests: move now-generic quota tests to generic
  * xfs: make some xfs project quota tests generic
  * fstests: move now-generic xfs project quota tests generic
  * generic: truncate heavily reflinked file
  * btrfs: test free space tree mount options
* Tue Oct  4 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160817:
  * xfs/234: use scratch device helpers
  * common/rc: optionally test xfs_repair index rebuilding
  * xfs/128: cycle_mount the scratch device
  * common/dmerror: fix mount option issues
  * xfs: test attr_list_by_handle cursor iteration
  * common/defrag: rework _require_defrag for ext4
  * ext4: Test expansion of inode size
  * generic: test accurate shared extent reporting
  * README: document Fedora, RHEL, and CentOS dependencies
  * fstests: repository @ oss.sgi.com no longer used
* Thu Jul 28 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160721:
  * generic/294: filter quotes from mknod
  * common/rc: ext4 doesn't support O_DIRECT with encryption
  * generic/082: rename _filter_project_quota to a avoid function name conflict
  * fstests: Add / use _require_runas and _runas
  * generic: Add richacl tests
  * btrfs/048: extend _filter_btrfs_prop_error to handle additional errors
  * generic/042: remove from quick group
  * overlay: dentry leak for default_permissions mount option
  * overlay: remove dir which contains whiteout from lower dir
  * common: support dm-delay to introduce I/O delays
  * xfs: test for post umount readahead completion panic
  * btrfs: add functions to set and reset required number of SCRATCH_DEV_POOL
  * btrfs: add functions to get and put a device for replace target
  * btrfs/027: make use of new device get and put helper functions
  * btrfs: add helper function to check if btrfs is module
  * btrfs: test RAID1 device reappear and balance
  * btrfs: test RAID5 device reappear and balance
  * btrfs: EDQUOTA leaks reserved data space
  * quota: fix generic/244 on 32-bit platforms
  * common/dmerror: fix nonsensical arguments handling
  * xfs: configurable behavior on errors at unmount time
  * xfs/122: fix test output to reflect latest xfsprogs
  * xfs/235: fix logic errors when checking rmap usage after failures
  * xfs/229: require 3GB of space
  * generic/204: increase log size for rmap/reflink
  * xfs/128: use $XFS_FSR_PROG instead of xfs_fsr directly
  * xfs: inject errors at various parts of the deferred op completion
  * xfs: test clearing reflink inode flag
  * ext4/021: add _require_metadata_journaling
  * btrfs/079: Fix wrong value passed to available space check
  * btrfs: incremental send after moving directories around
  * btrfs: incremental send after removing a directory
  * btrfs: invalid rmdir issued by send operation
  * common/rc: add _require_xfs_mkfs_validation
  * xfs/096: run test only if mkfs.xfs accepts invalid inputs
  * generic: add _require_block_device to more tests
  * common/rc: avoid mkfs option conflicts in _scratch_mkfs_xfs_supported
  * xfs: fix wrong seq order in group file
  * generic/120: requires working *atime mount options
  * build: Fix installation for extended names
  * check: fix extended names handling
  * check: remove unused variable
  * xfs: Add mkfs input validation tests
  * xfs/083: disable dmesg check
  * btrfs: send on fully deduped file
  * generic/075,112: fix up fsx error handling
  * generic/294: Filter backquotes from mknod error output
  * common/filter: Improve xfs_io filter
  * btrfs: Update quick and auto tag for btrfs group
  * generic/235: Fix false failures for some quota formats
* Sun Jul  3 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160624:
  * xfs/186: fix test for crc=0, ftype=1
  * xfs/186: run test on expected XFS configuration
  * dmthin: express low_water in cluster_size not sector size
  * generic/026: This test doesn't require runas
  * overlay: test visible whiteout issue after rename
  * overlay: getcwd() after a failed rmdir
  * overlay: create new file over whiteout
  * btrfs/006: ignore btrfs filesystem sync stdout output
  * fstests: introduce _exclude_scratch_mount_option helper
  * ext4/271: _notrun if there are journal related mount options
* Mon May  9 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160509:
  * dm-thinp demo test
  * overlay: test basic whiteout
  * overlay: notrun if upper fs does not support d_type
  * overlay: test copy up by changing mode bits
  * btrfs: Test that qgroup counts are valid after snapshot creation
  * generic: test creating a symlink and then fsync its parent directory
  * btrfs: add replace missing and replace RAID 5/6 to profile configs
  * btrfs: add test for replacing a missing device
  * fstests: fix various $seqres.full issues
  * generic: renumber tests after merge
* Wed Apr  6 2016 mpluskal@suse.com
- Update to version 1.1.1+git.20160405:
  * lib/tlibio: Fix a build warning
  * btrfs: test log replay with qgroups enabled and orphan roots
  * generic/338: Add mmap race test
  * common: make sure dm device is all settled before removing it
  * btrfs: add test for fsync after snapshot deletion
  * check: make results/check.log match everybody else
  * common: replace chattr with $CHATTR_PROG
  * generic/244: avoid creating too large random ID
  * xfs/206: filter out reflink related outputs
  * generic: add test for fsync after renaming directory
  * generic: add test for fsync after renaming file
  * xfs/030: filter out repeated lines from .out files
  * attr: adjust acl_max of f2fs if inline_xattr is set
  * common: Mark tests which use direct I/O with _requires_odirect
  * generic/082: filter out project quota status
* Fri Apr  1 2016 mpluskal@suse.com
- Update to version 1.1.1~git.20160323:
- Replace export-xfstests-git.sh with _service
- Cleanup spec file with spec-cleaner
- Make building more verbose
* Wed Mar 23 2016 dsterba@suse.cz
- update to git b90938ec1de6
* Tue Feb 23 2016 dsterba@suse.cz
- update to git fdf1c150a0e0
* Tue Feb 16 2016 dsterba@suse.cz
- update to git 74b326f9a616
* Tue Feb  9 2016 dsterba@suse.cz
- update to git d98149c20555
- add more dependencies to build fssum and dbtest
* Mon Nov  2 2015 dsterba@suse.cz
- update to git 8deb63509840
* Mon Jun  1 2015 dsterba@suse.cz
- update to git 78bbab93d8e8
* Fri May  8 2015 dsterba@suse.cz
- update to git c3d3e1e4bc06
* Wed Apr  8 2015 dsterba@suse.cz
- update to git facff609afd6
* Wed Mar  4 2015 dsterba@suse.cz
- update to git e020a49a70b3
* Thu Jan 29 2015 dsterba@suse.cz
- update to git 573f9ca7bc53
* Thu Dec 18 2014 dsterba@suse.cz
- update to git 46a08542e342
* Sat Oct 18 2014 dsterba@suse.cz
- update to git 481c28f52fd4
* Sat Oct  4 2014 dsterba@suse.cz
- update to git 48c45430ce4b
- spec: require the basic filesystem tools
* Mon Sep  8 2014 dsterba@suse.cz
- update to git f7d0a306291a
* Tue Jul 22 2014 dsterba@suse.cz
- update to git c728752cfaab
* Fri Mar 21 2014 dsterba@suse.cz
- update git exporter
- update to 1.1.1, git snapshot f1dcf49c11eb
- spec cleanup
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Remove non-existing Buildrequired packages
* Thu Nov  3 2011 dsterba@suse.cz
- update to git 868a386
- time to change changelog time
* Fri Oct 14 2011 dsterba@suse.cz
- update to git 73a57c6
- This is the firsteversioned release recorded for the
  xfstests suite.  Tests 240-263 have been added to the
  suite (to date) in 2011.
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 1a9e9e0
* Mon Aug 15 2011 dsterba@suse.cz
- update to git d6f51d9
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 314b221
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 99102d6
* Mon Aug 15 2011 dsterba@suse.cz
- update to git de164fb
* Mon Aug 15 2011 dsterba@suse.cz
- update to git 392c442
* Mon Aug 15 2011 dsterba@suse.cz
- initial checkin
